/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dnd;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.EditPart;
import org.fortiss.tooling.base.ui.editpart.RootEditPartBase;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;

/**
 * Composition context for GEF edit parts initiated by a drop gesture. The
 * context content is defined by the editpart that was the drop target and the
 * mouse position.
 * <P>
 * The editpart can also be a root edit part, e.g. the background of some
 * editor.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: F41CA022ECFE85D93C254EFB2BE6D7BE
 */
public class DropContext implements IElementCompositionContext {

	/** Drop target edit part */
	private final EditPart dropTarget;

	/** Position. */
	private final Point position;

	/** Constructor. */
	public DropContext(EditPart dropTarget, Point position) {
		this.dropTarget = dropTarget;
		this.position = position;
	}

	/** Returns the position. */
	public Point getPosition() {
		return position;
	}

	/** Returns the drop target edit part. */
	public EditPart getDropTarget() {
		return dropTarget;
	}

	/** Returns whether drop target is root edit part (base). */
	public boolean isRoot() {
		return dropTarget instanceof RootEditPartBase;
	}
}
