/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.figure;

import org.eclipse.draw2d.Figure;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.Label;
import org.eclipse.draw2d.LayoutManager;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Rectangle;

/**
 * This class implements dynamic behavior of a labeled connector figure, which
 * displays the label if the figure has no connections.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class LabeledConnectorFigure extends Figure {

	/** Stores the base figure. */
	private final IFigure baseFigure;

	/** Stores the label figure. */
	private final Label label;

	/** Stores the default connector figure bounds. */
	private final Rectangle connectorFigureBounds;

	/** Stores the default dimension of the connector. */
	private final Dimension connectorDimension;

	/** Constructor. */
	public LabeledConnectorFigure(IFigure baseFigure, Label label,
			Dimension connectorDimension, Rectangle connectorFigureBounds) {
		this.baseFigure = baseFigure;
		this.label = label;
		this.connectorDimension = connectorDimension;
		this.connectorFigureBounds = connectorFigureBounds;

		setSize(connectorDimension);
		setLayoutManager(new TheLayoutManager());
		add(baseFigure);
		add(label);
	}

	/** Returns the underlying base figure. */
	public IFigure getBaseFigure() {
		return baseFigure;
	}

	/** A layout manager used for the label layouting. */
	private class TheLayoutManager implements LayoutManager {
		/** {@inheritDoc} */
		@Override
		public Object getConstraint(IFigure child) {
			return null;
		}

		/** {@inheritDoc} */
		@Override
		public Dimension getMinimumSize(IFigure container, int wHint, int hHint) {
			return container.getMinimumSize();
		}

		/** {@inheritDoc} */
		@Override
		public Dimension getPreferredSize(IFigure container, int wHint,
				int hHint) {
			return container.getPreferredSize();
		}

		/** {@inheritDoc} */
		@Override
		public void layout(IFigure container) {
			Rectangle containerBounds = new Rectangle(container.getBounds());

			// compute base bounds
			Rectangle baseBounds = new Rectangle(connectorFigureBounds);
			baseBounds.x += containerBounds.x;
			baseBounds.y += containerBounds.y;
			baseFigure.setBounds(baseBounds);

			// compute label size
			Rectangle labelTextBounds = label.getTextBounds();
			Rectangle newBounds = new Rectangle(containerBounds);
			newBounds.x += connectorDimension.width / 2;
			newBounds.y += (connectorDimension.height - labelTextBounds.height) / 2;
			// +1 needed for proper display
			newBounds.width += 1 + labelTextBounds.width;
			newBounds.height = labelTextBounds.height;
			label.setBounds(newBounds);

			// compute container bounds
			// +1 needed for proper display
			containerBounds.width = labelTextBounds.width
					+ connectorDimension.width + 1;
			containerBounds.height = connectorDimension.height;
			container.setBounds(containerBounds);
		}

		/** {@inheritDoc} */
		@Override
		public void remove(IFigure child) {
			// nothing to do
		}

		/** {@inheritDoc} */
		@Override
		public void invalidate() {
			// nothing to do
		}

		/** {@inheritDoc} */
		@Override
		public void setConstraint(IFigure child, Object constraint) {
			// nothing to do
		}
	}
}
