/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.layout.util;

import org.fortiss.tooling.base.model.layout.Dimension;
import org.fortiss.tooling.base.model.layout.EOrientation;
import org.fortiss.tooling.base.model.layout.LayoutFactory;
import org.fortiss.tooling.base.model.layout.Offset;
import org.fortiss.tooling.base.model.layout.OffsetOrientation;
import org.fortiss.tooling.base.model.layout.Orientation;
import org.fortiss.tooling.base.model.layout.Point;
import org.fortiss.tooling.base.ui.layout.constants.RecommendedLayoutConstants;

/**
 * Class for handling orientation relative coordinates.
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 0C2C5F21C2F2ECCCF9F45819D868FFA0
 */
public class OrientationUtils {

	/** Return the absolute position for a given orientation. */
	public static Point getAbsolute(Orientation orientation, Offset offset,
			Dimension parentSize, int parentInsets) {
		Point pos = LayoutDataUtils.createPoint(0, 0);
		int offsetValue = offset.getOffset();
		switch (orientation.getOrientation()) {
		case NORTH:
			pos.setX(offsetValue);
			pos.setY(0);
			break;
		case WEST:
			pos.setX(0);
			pos.setY(offsetValue);
			break;
		case SOUTH:
			pos.setX(offsetValue);
			pos.setY(parentSize.getHeight() - 2 * parentInsets);
			break;
		case EAST:
			pos.setX(parentSize.getWidth() - 2 * parentInsets);
			pos.setY(offsetValue);
			break;
		}

		return pos;
	}

	/**
	 * Return the absolute position for the given orientation using default
	 * insets.
	 */
	public static Point getAbsolute(Orientation orientation, Offset offset,
			Dimension parentSize) {
		return getAbsolute(orientation, offset, parentSize,
				RecommendedLayoutConstants.RECTANGULAR_SHAPE_INSETS);
	}

	/** Returns a new {@link OffsetOrientation} object with the given values. */
	public static OffsetOrientation createOffsetOrientation(
			EOrientation orientation, int offset) {
		OffsetOrientation oo = LayoutFactory.eINSTANCE
				.createOffsetOrientation();
		oo.setOrientation(orientation);
		oo.setOffset(offset);
		return oo;
	}

	/** Returns a new Orientation object with the given value. */
	public static Orientation createOrientation(EOrientation orientation) {
		Orientation o = LayoutFactory.eINSTANCE.createOrientation();
		o.setOrientation(orientation);
		return o;
	}

	/** Returns a new Offset object with the given value. */
	public static Offset createOffset(int offset) {
		Offset o = LayoutFactory.eINSTANCE.createOffset();
		o.setOffset(offset);
		return o;
	}
}
