/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal;

import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.service.IActionService;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;

/**
 * This class implements the {@link IContextMenuService} interface.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: E98FC60498F584BDB4950E792DB3B708
 */
public class ContextMenuService implements IContextMenuService {

	/** {@inheritDoc} */
	@Override
	public MenuManager createDefaultContextMenu(
			IContextMenuContributor menuContributor) {
		MenuManager menuManager = new MenuManager("#PopupMenu");
		menuManager.setRemoveAllWhenShown(true);
		menuManager.addMenuListener(new MenuCreator(menuContributor));

		Separator repositorySection = new Separator("repository");
		repositorySection.setVisible(true);
		menuManager.add(repositorySection);

		return menuManager;
	}

	/** Wrapper class for menu creation. */
	private static class MenuCreator implements IMenuListener {

		/** Stores the custom menu contributor. */
		private final IContextMenuContributor contributor;

		/** Constructor. */
		public MenuCreator(IContextMenuContributor contributor) {
			this.contributor = contributor;
		}

		/** {@inheritDoc} */
		@Override
		public void menuAboutToShow(IMenuManager menu) {
			if (!menu.isEmpty()) {
				return;
			}
			addVisibleSectionSeparator(menu, CUSTOM_MENU_SEPARATOR_ID);
			addVisibleSectionSeparator(menu,
					ActionService.GROUP_GLOBAL_DEFAULTS);
			addVisibleSectionSeparator(menu, REPOSITORY_MENU_SEPARATOR_ID);
			addVisibleSectionSeparator(menu,
					IWorkbenchActionConstants.MB_ADDITIONS);

			if (contributor != null) {
				for (IContributionItem item : contributor.getContributedItems()) {
					menu.appendToGroup(CUSTOM_MENU_SEPARATOR_ID, item);
				}
			}
			IActionService.INSTANCE.addGlobalDefaultActionSectionToMenu(menu);
		}
	}

	/** Adds a visible section separator. */
	private static void addVisibleSectionSeparator(IMenuManager menu,
			String sectionName) {
		Separator separator = new Separator(sectionName);
		separator.setVisible(true);
		menu.add(separator);
	}
}
