/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.BaseLabelProvider;
import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.swt.graphics.Image;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * {@link ILabelProvider} for the model navigator tree.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: E29E85F62F5A2BDCFB18A856F52F8C7E
 */
public final class NavigatorTreeLabelProvider extends BaseLabelProvider
		implements ILabelProvider {

	/** {@inheritDoc} */
	@Override
	public Image getImage(Object element) {
		// delegate to the model element handlers
		if (element instanceof EObject) {
			IModelElementHandler<EObject> handler = IModelElementHandlerService.INSTANCE
					.getModelElementHandler((EObject) element);
			if (handler != null) {
				return handler.getIcon();
			}
		}
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		// delegate to the model element handlers
		if (element instanceof EObject) {
			IModelElementHandler<EObject> handler = IModelElementHandlerService.INSTANCE
					.getModelElementHandler((EObject) element);
			if (handler != null) {
				return handler.getName((EObject) element);
			}
		}
		return "";
	}
}
