/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.service;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.Saveable;
import org.fortiss.tooling.kernel.ui.internal.NavigatorService;

/**
 * The navigator service provides model navigation support. Its main
 * contribution is the navigator Eclipse view, which shows the model content
 * starting with the top-level elements and using the information provided by
 * {@link IModelElementHandlerService}.
 * 
 * <P>
 * The navigator service is also responsible to integrate with the Eclipse IDE
 * regarding model file save support.
 * 
 * <P>
 * The navigator service does not provide any extensions.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: D5C6C639C61EE41DB15E053A3D64B09B
 */
public interface INavigatorService {
	/** Returns the singleton instance of the service. */
	public static final INavigatorService INSTANCE = new NavigatorService();

	/** Returns view id of the navigator view. */
	public static final String NAVIGATOR_VIEW = "org.fortiss.tooling.kernel.model.navigator";

	/** Returns the current naviaator selection. */
	ISelection getCurrentSelection();

	/** Returns the saveables. */
	Saveable[] getSaveables();

	/** Returns the saveables of the current selection. */
	Saveable[] getActiveSaveables();

	/** Reveals the given model element. */
	void revealModelElement(EObject modelElement);

	/** Refreshes the navigator view part. */
	void refresh();
}
