/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;

/**
 * Prototypes consist of a generic description and pre-configured
 * {@link EObject}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 1D8DA4B2312BAB5112C0FDEA9EADB8E0
 */
public final class Prototype {

	/** The generic prototype name. */
	private final String name;
	/** The pre-configured {@link EObject}. */
	private final EObject prototype;

	/** Constructor. */
	public Prototype(String name, EObject prototype) {
		this.name = name;
		this.prototype = prototype;
	}

	/** Returns the name. */
	public String getName() {
		return name;
	}

	/** Returns the prototype instance (NOT a copy!). */
	public EObject getPrototype() {
		return prototype;
	}

	/**
	 * Returns a copy of the prototype. This method is potentially expensive.
	 */
	public EObject getPrototypeCopy() {
		return EcoreUtil.copy(prototype);
	}
}
