/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.internal.CommandStackService;

/**
 * The command stack service manages the access to the command stack and editing
 * domain. It provides a Undo/Redo mechanism and allows {@link Runnable}s to be
 * executed, which need to modify the model. It also provides a view on the
 * underlying persistency mechanism by providing a dirty state and a save
 * method.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 0673CEE9D531862ED2BEB34AFCB77AED
 */
public interface ICommandStackService {

	/** Returns the singleton instance of the service. */
	public static final ICommandStackService INSTANCE = new CommandStackService();

	/** Runs the given {@link Runnable} within a emfStore transaction. */
	void runAsCommand(EObject target, Runnable runner);

	/** Checks if an undo command is possible on the given target's project. */
	boolean canUndo(EObject target);

	/** Executes the undo command on the target's project. */
	void undo(EObject target);

	/** Checks if a redo command is possible on the given target's project. */
	boolean canRedo(EObject target);

	/** Executes the redo command on the target's project. */
	void redo(EObject target);

	/** Returns the dirty state of the given target's project. */
	boolean isDirty(EObject target);

	/** Saves the given target's project. */
	void doSave(EObject target, IProgressMonitor monitor);
}
